SchemaSpy - Table gnss_data.public.rinex_tank_struct

Tables Relationships Utility Tables Constraints Anomalies Columns Donate

Table gnss_data.public.rinex_tank_struct | Generated by SchemaSpy

Related columns Constraints Comments Legend |
Legend: |
Primary key columns
Columns with indexes
Implied relationships
Excluded column relationships
< n > number of related tables
Column | Type | Size | Nulls | Auto | Default | Children | Parents | Comments
--- | --- | --- | --- | --- | --- | --- | --- | ---
Level | int4 | 10 |  |  |  |  |  |
KeyCode | varchar | 7 | √ |  | null |  |
keys.KeyCode | rinex_tank_struct_key_fkey R
Table contained 3 rows at Fri Jul 28 14:55 EDT 2017

Close relationships: